@@ -1,6 +1,6 @@
-#line 1 "inc/Module/Install/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.0/Module/Install/PAR.pm"
+#line 1 "inc/Module/Install/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.4/Module/Install/PAR.pm"
 # $File: //depot/cpan/Module-Install/lib/Module/Install/PAR.pm $ $Author: autrijus $
-# $Revision: #22 $ $Change: 1481 $ $DateTime: 2003/05/07 10:41:22 $ vim: expandtab shiftwidth=4
+# $Revision: #28 $ $Change: 1650 $ $DateTime: 2003/07/29 06:03:27 $ vim: expandtab shiftwidth=4
 
 package Module::Install::PAR;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -111,19 +111,12 @@ sub make_par {
     my ($self, $file) = @_;
     unlink $file if -f $file;
 
-    if (eval { require Archive::Zip; 1 }) {
-        my $zip = Archive::Zip->new;
-        $zip->addTree( 'blib', '' );
-        $zip->writeToFileNamed( $file ) == AZ_OK or die $!;
-    }
-    elsif ($self->can_run('zip')) {
-        mkdir('blib', 0777);
-        chdir('blib');
-        system(qw(zip -r), "../$file", '.') and die $!;
-        chdir('..');
+    unless ( eval { require PAR::Dist; PAR::Dist->VERSION >= 0.03 } ) {
+        warn "Please install PAR::Dist 0.03 or above first.";
+        return;
     }
 
-    print "Successfully created binary distribution '$file'.\n";
+    return PAR::Dist::blib_to_par(dist => $file);
 }
 
 1;
