@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
-# $File: //member/autrijus/PAR/script/par.pl $ $Author: autrijus $
-# $Revision: #102 $ $Change: 10404 $ $DateTime: 2004/03/17 11:50:19 $ vim: expandtab shiftwidth=4
+# $File: /depot/local/PAR/trunk/script/par.pl $ $Author: autrijus $
+# $Revision: #71 $ $Change: 11731 $ $DateTime: 2004-08-30T22:40:26.326020Z $ vim: expandtab shiftwidth=4
 
 package __par_pl;
 
@@ -187,18 +187,13 @@ my %Config = (
 _set_progname();
 _set_par_temp();
 
-# Append ".exe" to $0 if it was missing
-$0 .= $Config{_exe} if $Config{_exe}
-    and $progname =~ /\Q$Config{_exe}\E$/
-    and $0 !~ /\Q$Config{_exe}\E$/;
-
 # Magic string checking and extracting bundled modules {{{
 my ($start_pos, $data_pos);
 {
     local $SIG{__WARN__} = sub {};
 
     # Check file type, get start of data section {{{
-    open _FH, $progname or last;
+    open _FH, '<', $progname or last;
     binmode(_FH);
 
     my $buf;
@@ -290,7 +285,7 @@ my ($start_pos, $data_pos);
                 print $out $filename->{buf};
                 close $out;
             }
-            open my $fh, $name or die $!;
+            open my $fh, '<', $name or die $!;
             binmode($fh);
             return $fh;
         }
@@ -497,13 +492,17 @@ if ($out) {
                 $content = $file->{buf};
             }
             else {
-                open FILE, "$file" or die "Can't open $file: $!";
+                open FILE, '<', $file or die "Can't open $file: $!";
                 binmode(FILE);
                 $content = <FILE>;
                 close FILE;
 
                 PAR::Filter::PodStrip->new->apply(\$content, $file)
-                    if !$ENV{PAR_VERBATIM} and lc($name) =~ /\.(?:pm|ix|al)$/i;
+                    if !$ENV{PAR_VERBATIM} and $name =~ /\.(?:pm|ix|al)$/i;
+
+                # Do not let XSLoader pick up auto/* from environment
+                $content =~ s/goto +retry +unless +.*/goto retry;/
+                    if lc($name) eq lc("XSLoader.pm");
             }
 
             outs(qq(Written as "$name"));
@@ -531,10 +530,12 @@ if ($out) {
 }
 # }}}
 
-# Prepare $0 into PAR file cache {{{
+# Prepare $progname into PAR file cache {{{
 {
     last unless defined $start_pos;
 
+    _fix_progname();
+
     # Now load the PAR file and put it into PAR::LibCache {{{
     require PAR;
     PAR::Heavy::_init_dynaloader();
@@ -546,7 +547,7 @@ if ($out) {
     $zip->readFromFileHandle($fh) == Archive::Zip::AZ_OK() or die "$!: $@";
 
     push @PAR::LibCache, $zip;
-    $PAR::LibCache{$0} = $zip;
+    $PAR::LibCache{$progname} = $zip;
 
     $quiet = !$ENV{PAR_DEBUG};
     outs(qq(\$ENV{PAR_TEMP} = "$ENV{PAR_TEMP}"));
@@ -572,12 +573,12 @@ if ($out) {
 # }}}
 
 # If there's no main.pl to run, show usage {{{
-unless ($PAR::LibCache{$0}) {
+unless ($PAR::LibCache{$progname}) {
     die << "." unless @ARGV;
 Usage: $0 [ -Alib.par ] [ -Idir ] [ -Mmodule ] [ src.par ] [ program.pl ]
        $0 [ -B|-b ] [-Ooutfile] src.par
 .
-    $0 = shift(@ARGV);
+    $ENV{PAR_PROGNAME} = $progname = $0 = shift(@ARGV);
 }
 # }}}
 
@@ -598,6 +599,7 @@ sub require_modules {
     require File::Spec;
     require XSLoader;
     require Config;
+    require IO::Handle;
     require IO::File;
     require Compress::Zlib;
     require Archive::Zip;
@@ -616,7 +618,7 @@ sub _set_par_temp {
 
     foreach my $path (
         (map $ENV{$_}, qw( TMPDIR TEMP TMP )),
-        qw( "C:\\TEMP /tmp . )
+        qw( C:\\TEMP /tmp . )
     ) {
         next unless $path and -d $path and -w $path;
         my $username = defined(&Win32::LoginName)
@@ -630,7 +632,7 @@ sub _set_par_temp {
             my $ctx = eval { require Digest::SHA1; Digest::SHA1->new }
                    || eval { require Digest::MD5; Digest::MD5->new };
 
-            if ($ctx and open(my $fh, "<$progname")) {
+            if ($ctx and open(my $fh, "<", $progname)) {
                 binmode($fh);
                 $ctx->addfile($fh);
                 close($fh);
@@ -675,22 +677,38 @@ sub _set_progname {
     if ($ENV{PAR_PROGNAME} and $ENV{PAR_PROGNAME} =~ /(.+)/) {
         $progname = $1;
     }
-    return if -s ($progname ||= $0);
 
-    if (-s "$progname$Config{_exe}") {
-        $ENV{PAR_PROGNAME} = $progname = "$progname$Config{_exe}";
-        $0 .= $Config{_exe};
-        return $progname;
+    $progname ||= $0;
+
+    if ($ENV{PAR_TEMP} and index($progname, $ENV{PAR_TEMP}) >= 0) {
+        $progname = substr($progname, rindex($progname, $Config{_delim}) + 1);
+    }
+
+    if (!$ENV{PAR_PROGNAME} or index($progname, $Config{_delim}) >= 0) {
+        if (open my $fh, '<', $progname) {
+            return if -s $fh;
+        }
+        if (-s "$progname$Config{_exe}") {
+            $progname .= $Config{_exe};
+            return;
+        }
     }
 
     foreach my $dir (split /\Q$Config{path_sep}\E/, $ENV{PATH}) {
+        next if exists $ENV{PAR_TEMP} and $dir eq $ENV{PAR_TEMP};
         $dir =~ s/\Q$Config{_delim}\E$//;
         (($progname = "$dir$Config{_delim}$progname$Config{_exe}"), last)
             if -s "$dir$Config{_delim}$progname$Config{_exe}";
         (($progname = "$dir$Config{_delim}$progname"), last)
             if -s "$dir$Config{_delim}$progname";
     }
+}
 
+sub _fix_progname {
+    $0 = $progname ||= $ENV{PAR_PROGNAME};
+    if (index($progname, $Config{_delim}) < 0) {
+        $progname = ".$Config{_delim}$progname";
+    }
     $ENV{PAR_PROGNAME} = $progname;
 }
 
@@ -725,7 +743,7 @@ sub outs {
         print $logfh "@_\n";
     }
     else {
-        warn "@_\n";
+        print "@_\n";
     }
 }
 
@@ -746,10 +764,10 @@ require PAR;
 unshift @INC, \&PAR::find_par;
 PAR->import(@par_args);
 
-die qq(Can't open perl script "$0": No such file or directory\n)
-    unless -e $0;
+die qq(Can't open perl script "$progname": No such file or directory\n)
+    unless -e $progname;
 
-do $0;
+do $progname;
 die $@ if $@;
 
 };
